summaryrefslogtreecommitdiff
path: root/tinyusb
diff options
context:
space:
mode:
authorhathach <[email protected]>2018-03-02 15:28:40 +0700
committerhathach <[email protected]>2018-03-02 15:28:40 +0700
commitdc12e55c568a182ac95e4e7594e0059c1b8f7f4b (patch)
tree5f4dc1d459c081ae6bf62ea781834d86f1f9d042 /tinyusb
parentb6e337bc12c041969687ee8c13dbe5045c4096f8 (diff)
rename hal_interrupt_* to hal_usb_int_*
Diffstat (limited to 'tinyusb')
-rw-r--r--tinyusb/hal/hal.h4
-rw-r--r--tinyusb/hal/hal_lpc11uxx.c4
-rw-r--r--tinyusb/hal/hal_lpc13uxx.c4
-rw-r--r--tinyusb/hal/hal_lpc175x_6x.c4
-rw-r--r--tinyusb/osal/osal_none.h6
-rw-r--r--tinyusb/tusb.c4
6 files changed, 13 insertions, 13 deletions
diff --git a/tinyusb/hal/hal.h b/tinyusb/hal/hal.h
index 65b219610..f395c6d23 100644
--- a/tinyusb/hal/hal.h
+++ b/tinyusb/hal/hal.h
@@ -74,14 +74,14 @@ tusb_error_t hal_init(void);
* \note Some MCUs such as NXP LPC43xx has multiple USB controllers. It is necessary to know which USB controller for
* those MCUs.
*/
-void hal_interrupt_enable(uint8_t coreid);
+void hal_usb_int_enable(uint8_t coreid);
/** \brief Disable USB Interrupt on a specific USB Controller
* \param[in] coreid is a zero-based index to identify USB controller's ID
* \note Some MCUs such as NXP LPC43xx has multiple USB controllers. It is necessary to know which USB controller for
* those MCUs.
*/
-void hal_interrupt_disable(uint8_t coreid);
+void hal_usb_int_disable(uint8_t coreid);
#include "hal_usb.h"
diff --git a/tinyusb/hal/hal_lpc11uxx.c b/tinyusb/hal/hal_lpc11uxx.c
index 36755bdd5..f240597cc 100644
--- a/tinyusb/hal/hal_lpc11uxx.c
+++ b/tinyusb/hal/hal_lpc11uxx.c
@@ -41,13 +41,13 @@
#if TUSB_CFG_MCU == MCU_LPC11UXX
-void hal_interrupt_enable(uint8_t coreid)
+void hal_usb_int_enable(uint8_t coreid)
{
(void) coreid; // discard compiler's warning
NVIC_EnableIRQ(USB_IRQn);
}
-void hal_interrupt_disable(uint8_t coreid)
+void hal_usb_int_disable(uint8_t coreid)
{
(void) coreid; // discard compiler's warning
NVIC_DisableIRQ(USB_IRQn);
diff --git a/tinyusb/hal/hal_lpc13uxx.c b/tinyusb/hal/hal_lpc13uxx.c
index afa67ff21..a8969a2f7 100644
--- a/tinyusb/hal/hal_lpc13uxx.c
+++ b/tinyusb/hal/hal_lpc13uxx.c
@@ -41,13 +41,13 @@
#if TUSB_CFG_MCU == MCU_LPC13UXX
-void hal_interrupt_enable(uint8_t coreid)
+void hal_usb_int_enable(uint8_t coreid)
{
(void) coreid; // discard compiler's warning
NVIC_EnableIRQ(USB_IRQ_IRQn);
}
-void hal_interrupt_disable(uint8_t coreid)
+void hal_usb_int_disable(uint8_t coreid)
{
(void) coreid; // discard compiler's warning
NVIC_DisableIRQ(USB_IRQ_IRQn);
diff --git a/tinyusb/hal/hal_lpc175x_6x.c b/tinyusb/hal/hal_lpc175x_6x.c
index f7f1d6a7d..32be8f3fe 100644
--- a/tinyusb/hal/hal_lpc175x_6x.c
+++ b/tinyusb/hal/hal_lpc175x_6x.c
@@ -41,13 +41,13 @@
#if TUSB_CFG_MCU == MCU_LPC175X_6X
-void hal_interrupt_enable(uint8_t coreid)
+void hal_usb_int_enable(uint8_t coreid)
{
(void) coreid; // discard compiler's warning
NVIC_EnableIRQ(USB_IRQn);
}
-void hal_interrupt_disable(uint8_t coreid)
+void hal_usb_int_disable(uint8_t coreid)
{
(void) coreid; // discard compiler's warning
NVIC_DisableIRQ(USB_IRQn);
diff --git a/tinyusb/tusb.c b/tinyusb/tusb.c
index 15aa1fae9..7adb5098c 100644
--- a/tinyusb/tusb.c
+++ b/tinyusb/tusb.c
@@ -53,11 +53,11 @@ tusb_error_t tusb_init(void)
#endif
#if (TUSB_CFG_CONTROLLER_0_MODE)
- hal_interrupt_enable(0);
+ hal_usb_int_enable(0);
#endif
#if (TUSB_CFG_CONTROLLER_1_MODE)
- hal_interrupt_enable(1);
+ hal_usb_int_enable(1);
#endif
return TUSB_ERROR_NONE;
diff --git a/tinyusb/osal/osal_none.h b/tinyusb/osal/osal_none.h
index 378a3a6f6..47f591675 100644
--- a/tinyusb/osal/osal_none.h
+++ b/tinyusb/osal/osal_none.h
@@ -191,11 +191,11 @@ static inline void osal_queue_flush(osal_queue_t const queue_hdl)
else\
return TUSB_ERROR_OSAL_WAITING;\
} else{\
/*TODO mutex lock hal_interrupt_disable */\
memcpy(p_data, queue_hdl->buffer + (queue_hdl->rd_idx * queue_hdl->item_size), queue_hdl->item_size);\
queue_hdl->rd_idx = (queue_hdl->rd_idx + 1) % queue_hdl->depth;\
queue_hdl->count--;\
/*TODO mutex unlock hal_interrupt_enable */\
*(p_error) = TUSB_ERROR_NONE;\
}\
}while(0)
@@ -245,7 +245,7 @@ static inline void osal_semaphore_reset(osal_semaphore_t sem_hdl)
else\
return TUSB_ERROR_OSAL_WAITING;\
} else{\
- if (sem_hdl->count) sem_hdl->count--; /*TODO mutex hal_interrupt_disable consideration*/\
+ if (sem_hdl->count) sem_hdl->count--; /*TODO mutex hal_usb_int_disable consideration*/\
*(p_error) = TUSB_ERROR_NONE;\
}\
}while(0)
@@ -191,11 +191,11 @@ static inline void osal_queue_flush(osal_queue_t const queue_hdl)
return TUSB_ERROR_OSAL_WAITING;\
} else{\
- /*TODO mutex lock hal_interrupt_disable */\
+ /*TODO mutex lock hal_usb_int_disable */\
memcpy(p_data, queue_hdl->buffer + (queue_hdl->rd_idx * queue_hdl->item_size), queue_hdl->item_size);\
queue_hdl->rd_idx = (queue_hdl->rd_idx + 1) % queue_hdl->depth;\
@@ -191,11 +191,11 @@ static inline void osal_queue_flush(osal_queue_t const queue_hdl)
queue_hdl->rd_idx = (queue_hdl->rd_idx + 1) % queue_hdl->depth;\
queue_hdl->count--;\
- /*TODO mutex unlock hal_interrupt_enable */\
+ /*TODO mutex unlock hal_usb_int_enable */\
*(p_error) = TUSB_ERROR_NONE;\
}\